@@ -185,15 +185,18 @@ class WebAPI:
         """
         return self._request('host', {'ip': ip})
     
-    def search(self, query):
+    def search(self, query, page=1):
         """Search the SHODAN database.
         
         Arguments:
         query    -- search query; identical syntax to the website
         
+        Optional arguments:
+        page     -- page number of the search results 
+        
         Returns:
         A dictionary with 3 main items: matches, countries and total.
         Visit the website for more detailed information.
         
         """
-        return self._request('search', {'q': query})
+        return self._request('search', {'q': query, 'page': page})
